==> huaweicloudsdkdsc-3.1.61-py2.py3-none-any.whl: huaweicloudsdkdsc/v1/model/change_rule_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ChangeRuleRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'body': 'RuleChangeRequest'
    }

    attribute_map = {
        'body': 'body'
    }

    def __init__(self, body=None):
        """ChangeRuleRequest

        The model defined in huaweicloud sdk

        :param body: Body of the ChangeRuleRequest
        :type body: :class:`huaweicloudsdkdsc.v1.RuleChangeRequest`
        """
        
        

        self._body = None
        self.discriminator = None

        if body is not None:
            self.body = body

    @property
    def body(self):
        """Gets the body of this ChangeRuleRequest.

        :return: The body of this ChangeRuleRequest.
        :rtype: :class:`huaweicloudsdkdsc.v1.RuleChangeRequest`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this ChangeRuleRequest.

        :param body: The body of this ChangeRuleRequest.
        :type body: :class:`huaweicloudsdkdsc.v1.RuleChangeRequest`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChangeRuleRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdsc-3.1.144-py2.py3-none-any.whl: huaweicloudsdkdsc/v1/model/change_rule_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ChangeRuleRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'body': 'RuleChangeRequest'
    }

    attribute_map = {
        'body': 'body'
    }

    def __init__(self, body=None):
        r"""ChangeRuleRequest

        The model defined in huaweicloud sdk

        :param body: Body of the ChangeRuleRequest
        :type body: :class:`huaweicloudsdkdsc.v1.RuleChangeRequest`
        """
        
        

        self._body = None
        self.discriminator = None

        if body is not None:
            self.body = body

    @property
    def body(self):
        r"""Gets the body of this ChangeRuleRequest.

        :return: The body of this ChangeRuleRequest.
        :rtype: :class:`huaweicloudsdkdsc.v1.RuleChangeRequest`
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this ChangeRuleRequest.

        :param body: The body of this ChangeRuleRequest.
        :type body: :class:`huaweicloudsdkdsc.v1.RuleChangeRequest`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChangeRuleRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
